function HH = filtrecos(N,M,Fc)
% HH = filtrecos(N,M,Fc)
%
% Cosine blur
% Eq. 51 of
% A SURE Approach for Digital Signal/Image Deconvolution Problems
% Jean-Christophe Pesquet, Amel Benazza-Benyahia, Caroline Chaux
% IEEE Transactions on Signal Processing, Vol. 57, No. 12, Dec. 2009, pp.
% 4616-4632.
%
%*****************************************************
%* author: Jean-Christophe PESQUET                   *
%* institution: LIGM - UMR CNRS 8049         	     *
%*	       Université Paris-Est                      *
%* date: Friday, July, 24th 2009                     *
%*****************************************************

if nargin == 2
    Fc = 0;
end

if Fc < 0 | Fc > 1/2
    error('cut off frequency should be between 0 and 1/2')
end

i0 = round(Fc*N)+1;

H1 = ones(1,N);
ind = i0:N/2;
if ~isempty(ind)
    H1(ind+1) = (cos(pi*(ind-i0)/(N/2-i0))+1)/2;
end
H1(N:-1:N/2+2) = H1(2:N/2);


H2 = ones(1,M);
ind = i0:M/2;
if ~isempty(ind)
    H2(ind+1) = (cos(pi*(ind-i0)/(M/2-i0))+1)/2;
end
H2(N:-1:N/2+2) = H2(2:N/2);

HH = H1'*H2;

